// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.cloud.discoveryengine.v1beta;

import "google/api/field_behavior.proto";

option csharp_namespace = "Google.Cloud.DiscoveryEngine.V1Beta";
option go_package = "cloud.google.com/go/discoveryengine/apiv1beta/discoveryenginepb;discoveryenginepb";
option java_multiple_files = true;
option java_outer_classname = "CompletionProto";
option java_package = "com.google.cloud.discoveryengine.v1beta";
option objc_class_prefix = "DISCOVERYENGINE";
option php_namespace = "Google\\Cloud\\DiscoveryEngine\\V1beta";
option ruby_package = "Google::Cloud::DiscoveryEngine::V1beta";

// Suggestion deny list entry identifying the phrase to block from suggestions
// and the applied operation for the phrase.
message SuggestionDenyListEntry {
  // Operator for matching with the generated suggestions.
  enum MatchOperator {
    // Default value. Should not be used
    MATCH_OPERATOR_UNSPECIFIED = 0;

    // If the suggestion is an exact match to the block_phrase, then block it.
    EXACT_MATCH = 1;

    // If the suggestion contains the block_phrase, then block it.
    CONTAINS = 2;
  }

  // Required. Phrase to block from suggestions served. Can be maximum 125
  // characters.
  string block_phrase = 1 [(google.api.field_behavior) = REQUIRED];

  // Required. The match operator to apply for this phrase. Whether to block the
  // exact phrase, or block any suggestions containing this phrase.
  MatchOperator match_operator = 2 [(google.api.field_behavior) = REQUIRED];
}
